@@ -1,12 +1,13 @@
 from fastapi import FastAPI
 from fastapi.middleware.cors import CORSMiddleware
 
-from apiautomata.routes import echo, home, missing
+from apiautomata.routes import echo, home, missing, proxy
 
 app = FastAPI()
 
 app.include_router(home.router)
 app.include_router(echo.router)
+app.include_router(proxy.router)
 app.include_router(missing.router)
 
 origins = ['*']
@@ -18,3 +19,13 @@ app.add_middleware(
     allow_methods=['*'],
     allow_headers=['*'],
 )
+
+
+@app.on_event('startup')
+async def startup_event():
+    print('Starting...')
+
+
+@app.on_event('shutdown')
+async def shutdown_event():
+    print('Stopping...')
